Documentation
¶
Index ¶
- type Dir
- type File
- type Resolver
- func (resolver *Resolver) ResolveDirectory(id lbdeploy.DirectoryResourceID) (ref lbdeploy.DirRef, err error)
- func (resolver *Resolver) ResolveFile(id lbdeploy.FileResourceID) (ref lbdeploy.FileRef, err error)
- func (resolver *Resolver) ResolveKnownFolder(id lbdeploy.DirectoryResourceID) (lbdeploy.KnownFolder, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Dir ¶
type Dir struct {
// contains filtered or unexported fields
}
Dir is an open directory on the local file system.
type File ¶
type File struct {
// contains filtered or unexported fields
}
File is an open file on the local file system.
type Resolver ¶
type Resolver struct {
// contains filtered or unexported fields
}
Resolver is capable of locating file system resources on the local system.
func NewResolver ¶
func NewResolver(resources lbdeploy.FileSystemResources) Resolver
NewResolver returns a new resolver for the given file system resources.
func (*Resolver) ResolveDirectory ¶
func (resolver *Resolver) ResolveDirectory(id lbdeploy.DirectoryResourceID) (ref lbdeploy.DirRef, err error)
ResolveDirectory resolves the requested directory resource, returning a directory reference that can be mapped to a path on the local system.
Successfully resolving a directory resource means that its path on the local system can be determined, but it does not imply that the directory exists.
If the directory cannot be resolved, an error is returned.
func (*Resolver) ResolveFile ¶
ResolveFile resolves the requested file resource, returning a file reference that can be mapped to a path on the local system.
Successfully resolving a file resource means that its path on the local system can be determined, but it does not imply that the file exists.
If the file cannot be resolved, an error is returned.
func (*Resolver) ResolveKnownFolder ¶
func (resolver *Resolver) ResolveKnownFolder(id lbdeploy.DirectoryResourceID) (lbdeploy.KnownFolder, error)
ResolveKnownFolder looks for a known folder with the given directory resource ID. If a known folder with the given ID is not recognized, it returns fs.ErrNotExist.